pywurfl.exceptions

Package pywurfl :: Module exceptions |
[hide private]
[frames] | no frames]

# Module exceptions

source code
Exception Classes

Author: Armand Lynch <lyncha@users.sourceforge.net>

Copyright: Copyright 2006-2008, Armand Lynch

License: LGPL

Classes | [hide private]
| WURFLException pywurfl base exception class.
| ExistsException General exception class
| DeviceNotFound Device Not Found exception class
| ActualDeviceRootNotFound Actual Device Root Not Found exception class

Variables | [hide private]
| __doc__ = ``...``
| __url__ = ``'``http://celljam.net/``'``

Variables Details | [hide private]

  ### __doc__ Value:
      """
      Exception Classes
      """